==> zio-aws-timestreamwrite_2.13-6.20.97.2-sources.jar: zio/aws/timestreamwrite/model/MixedMeasureMapping.scala <==
package zio.aws.timestreamwrite.model
import zio.aws.timestreamwrite.model.primitives.SchemaName
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class MixedMeasureMapping(
    measureName: Optional[SchemaName] = Optional.Absent,
    sourceColumn: Optional[SchemaName] = Optional.Absent,
    targetMeasureName: Optional[SchemaName] = Optional.Absent,
    measureValueType: zio.aws.timestreamwrite.model.MeasureValueType,
    multiMeasureAttributeMappings: Optional[
      Iterable[zio.aws.timestreamwrite.model.MultiMeasureAttributeMapping]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamwrite.model.MixedMeasureMapping = {
    import MixedMeasureMapping.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamwrite.model.MixedMeasureMapping
      .builder()
      .optionallyWith(
        measureName.map(value => SchemaName.unwrap(value): java.lang.String)
      )(_.measureName)
      .optionallyWith(
        sourceColumn.map(value => SchemaName.unwrap(value): java.lang.String)
      )(_.sourceColumn)
      .optionallyWith(
        targetMeasureName.map(value =>
          SchemaName.unwrap(value): java.lang.String
        )
      )(_.targetMeasureName)
      .measureValueType(measureValueType.unwrap)
      .optionallyWith(
        multiMeasureAttributeMappings.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.multiMeasureAttributeMappings)
      .build()
  }
  def asReadOnly: zio.aws.timestreamwrite.model.MixedMeasureMapping.ReadOnly =
    zio.aws.timestreamwrite.model.MixedMeasureMapping.wrap(buildAwsValue())
}
object MixedMeasureMapping {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamwrite.model.MixedMeasureMapping
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.timestreamwrite.model.MixedMeasureMapping =
      zio.aws.timestreamwrite.model.MixedMeasureMapping(
        measureName.map(value => value),
        sourceColumn.map(value => value),
        targetMeasureName.map(value => value),
        measureValueType,
        multiMeasureAttributeMappings.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def measureName: Optional[SchemaName]
    def sourceColumn: Optional[SchemaName]
    def targetMeasureName: Optional[SchemaName]
    def measureValueType: zio.aws.timestreamwrite.model.MeasureValueType
    def multiMeasureAttributeMappings: Optional[
      List[zio.aws.timestreamwrite.model.MultiMeasureAttributeMapping.ReadOnly]
    ]
    def getMeasureName: ZIO[Any, AwsError, SchemaName] =
      AwsError.unwrapOptionField("measureName", measureName)
    def getSourceColumn: ZIO[Any, AwsError, SchemaName] =
      AwsError.unwrapOptionField("sourceColumn", sourceColumn)
    def getTargetMeasureName: ZIO[Any, AwsError, SchemaName] =
      AwsError.unwrapOptionField("targetMeasureName", targetMeasureName)
    def getMeasureValueType
        : ZIO[Any, Nothing, zio.aws.timestreamwrite.model.MeasureValueType] =
      ZIO.succeed(measureValueType)
    def getMultiMeasureAttributeMappings: ZIO[Any, AwsError, List[
      zio.aws.timestreamwrite.model.MultiMeasureAttributeMapping.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "multiMeasureAttributeMappings",
      multiMeasureAttributeMappings
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamwrite.model.MixedMeasureMapping
  ) extends zio.aws.timestreamwrite.model.MixedMeasureMapping.ReadOnly {
    override val measureName: Optional[SchemaName] = zio.aws.core.internal
      .optionalFromNullable(impl.measureName())
      .map(value => zio.aws.timestreamwrite.model.primitives.SchemaName(value))
    override val sourceColumn: Optional[SchemaName] = zio.aws.core.internal
      .optionalFromNullable(impl.sourceColumn())
      .map(value => zio.aws.timestreamwrite.model.primitives.SchemaName(value))
    override val targetMeasureName: Optional[SchemaName] = zio.aws.core.internal
      .optionalFromNullable(impl.targetMeasureName())
      .map(value => zio.aws.timestreamwrite.model.primitives.SchemaName(value))
    override val measureValueType
        : zio.aws.timestreamwrite.model.MeasureValueType =
      zio.aws.timestreamwrite.model.MeasureValueType
        .wrap(impl.measureValueType())
    override val multiMeasureAttributeMappings: Optional[
      List[zio.aws.timestreamwrite.model.MultiMeasureAttributeMapping.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.multiMeasureAttributeMappings())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.timestreamwrite.model.MultiMeasureAttributeMapping.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamwrite.model.MixedMeasureMapping
  ): zio.aws.timestreamwrite.model.MixedMeasureMapping.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-timestreamwrite_3-6.20.162.1-sources.jar: zio/aws/timestreamwrite/model/MixedMeasureMapping.scala <==
package zio.aws.timestreamwrite.model
import zio.aws.timestreamwrite.model.primitives.SchemaName
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class MixedMeasureMapping(
    measureName: Optional[SchemaName] = Optional.Absent,
    sourceColumn: Optional[SchemaName] = Optional.Absent,
    targetMeasureName: Optional[SchemaName] = Optional.Absent,
    measureValueType: zio.aws.timestreamwrite.model.MeasureValueType,
    multiMeasureAttributeMappings: Optional[
      Iterable[zio.aws.timestreamwrite.model.MultiMeasureAttributeMapping]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamwrite.model.MixedMeasureMapping = {
    import MixedMeasureMapping.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamwrite.model.MixedMeasureMapping
      .builder()
      .optionallyWith(
        measureName.map(value => SchemaName.unwrap(value): java.lang.String)
      )(_.measureName)
      .optionallyWith(
        sourceColumn.map(value => SchemaName.unwrap(value): java.lang.String)
      )(_.sourceColumn)
      .optionallyWith(
        targetMeasureName.map(value =>
          SchemaName.unwrap(value): java.lang.String
        )
      )(_.targetMeasureName)
      .measureValueType(measureValueType.unwrap)
      .optionallyWith(
        multiMeasureAttributeMappings.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.multiMeasureAttributeMappings)
      .build()
  }
  def asReadOnly: zio.aws.timestreamwrite.model.MixedMeasureMapping.ReadOnly =
    zio.aws.timestreamwrite.model.MixedMeasureMapping.wrap(buildAwsValue())
}
object MixedMeasureMapping {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamwrite.model.MixedMeasureMapping
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.timestreamwrite.model.MixedMeasureMapping =
      zio.aws.timestreamwrite.model.MixedMeasureMapping(
        measureName.map(value => value),
        sourceColumn.map(value => value),
        targetMeasureName.map(value => value),
        measureValueType,
        multiMeasureAttributeMappings.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def measureName: Optional[SchemaName]
    def sourceColumn: Optional[SchemaName]
    def targetMeasureName: Optional[SchemaName]
    def measureValueType: zio.aws.timestreamwrite.model.MeasureValueType
    def multiMeasureAttributeMappings: Optional[
      List[zio.aws.timestreamwrite.model.MultiMeasureAttributeMapping.ReadOnly]
    ]
    def getMeasureName: ZIO[Any, AwsError, SchemaName] =
      AwsError.unwrapOptionField("measureName", measureName)
    def getSourceColumn: ZIO[Any, AwsError, SchemaName] =
      AwsError.unwrapOptionField("sourceColumn", sourceColumn)
    def getTargetMeasureName: ZIO[Any, AwsError, SchemaName] =
      AwsError.unwrapOptionField("targetMeasureName", targetMeasureName)
    def getMeasureValueType
        : ZIO[Any, Nothing, zio.aws.timestreamwrite.model.MeasureValueType] =
      ZIO.succeed(measureValueType)
    def getMultiMeasureAttributeMappings: ZIO[Any, AwsError, List[
      zio.aws.timestreamwrite.model.MultiMeasureAttributeMapping.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "multiMeasureAttributeMappings",
      multiMeasureAttributeMappings
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamwrite.model.MixedMeasureMapping
  ) extends zio.aws.timestreamwrite.model.MixedMeasureMapping.ReadOnly {
    override val measureName: Optional[SchemaName] = zio.aws.core.internal
      .optionalFromNullable(impl.measureName())
      .map(value => zio.aws.timestreamwrite.model.primitives.SchemaName(value))
    override val sourceColumn: Optional[SchemaName] = zio.aws.core.internal
      .optionalFromNullable(impl.sourceColumn())
      .map(value => zio.aws.timestreamwrite.model.primitives.SchemaName(value))
    override val targetMeasureName: Optional[SchemaName] = zio.aws.core.internal
      .optionalFromNullable(impl.targetMeasureName())
      .map(value => zio.aws.timestreamwrite.model.primitives.SchemaName(value))
    override val measureValueType
        : zio.aws.timestreamwrite.model.MeasureValueType =
      zio.aws.timestreamwrite.model.MeasureValueType
        .wrap(impl.measureValueType())
    override val multiMeasureAttributeMappings: Optional[
      List[zio.aws.timestreamwrite.model.MultiMeasureAttributeMapping.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.multiMeasureAttributeMappings())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.timestreamwrite.model.MultiMeasureAttributeMapping.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamwrite.model.MixedMeasureMapping
  ): zio.aws.timestreamwrite.model.MixedMeasureMapping.ReadOnly = new Wrapper(
    impl
  )
}
